@@ -1,6 +1,8 @@
 # Copyright 2015 NEC Corporation
 # All Rights Reserved.
 #
+# Copyright (c) 2022 Dell Inc. or its subsidiaries.
+#
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
 #    a copy of the License at
@@ -18,6 +20,8 @@ from oslo_config import cfg
 from tempest import config  # noqa
 
 
+# NOTE(TheJulia): The following options are loaded into a tempest
+# plugin configuration option via plugin.py.
 ironic_service_option = cfg.BoolOpt('ironic',
                                     default=False,
                                     help='Whether or not ironic is expected '
@@ -28,6 +32,18 @@ inspector_service_option = cfg.BoolOpt("ironic_inspector",
                                        help="Whether or not ironic-inspector "
                                        "is expected to be available")
 
+ironic_scope_enforcement = cfg.BoolOpt('ironic',
+                                       default=False,
+                                       help='Wheter or not ironic is '
+                                            'exepcted to enforce auth '
+                                            'scope.')
+
+inspector_scope_enforcement = cfg.BoolOpt('ironic_inspector',
+                                          default=False,
+                                          help='Whether or not '
+                                               'ironic-inspector is expected '
+                                               'to enforce auth scope.')
+
 baremetal_group = cfg.OptGroup(name='baremetal',
                                title='Baremetal provisioning service options',
                                help='When enabling baremetal tests, Nova '
@@ -38,6 +54,8 @@ baremetal_group = cfg.OptGroup(name='baremetal',
                                     'live_migration, pause, rescue, resize, '
                                     'shelve, snapshot, and suspend')
 
+# The bulk of the embedded configuration is below.
+
 baremetal_introspection_group = cfg.OptGroup(
     name="baremetal_introspection",
     title="Baremetal introspection service options",
@@ -61,6 +79,9 @@ BaremetalGroup = [
                         'publicURL', 'adminURL', 'internalURL'],
                help="The endpoint type to use for the baremetal provisioning"
                     " service"),
+    cfg.StrOpt('root_device_name',
+               default='/dev/md0',
+               help="Root device name to be used for node deployment"),
     cfg.IntOpt('deploywait_timeout',
                default=15,
                help="Timeout for Ironic node to reach the "
@@ -68,6 +89,10 @@ BaremetalGroup = [
     cfg.IntOpt('active_timeout',
                default=300,
                help="Timeout for Ironic node to completely provision"),
+    cfg.IntOpt('anaconda_active_timeout',
+               default=3600,
+               help="Timeout for Ironic node to completely provision "
+                    "when using the anaconda deployment interface."),
     cfg.IntOpt('association_timeout',
                default=30,
                help="Timeout for association of Nova instance and Ironic "
@@ -113,6 +138,40 @@ BaremetalGroup = [
                help="An MD5 checksum of the image."),
     cfg.StrOpt('partition_image_ref',
                help="UUID of the partitioned image to use in the tests."),
+    cfg.StrOpt('ramdisk_iso_image_ref',
+               help=("UUID (or url) of an ISO image for the ramdisk boot "
+                     "tests.")),
+    cfg.StrOpt('storage_inventory_file',
+               help="Path to storage inventory file for RAID cleaning tests."),
+    cfg.StrOpt('export_location',
+               help="Export config location for configuration molds."),
+    cfg.StrOpt('import_location',
+               help="Import config location for configuration molds."),
+    cfg.StrOpt('rollback_import_location',
+               help="Rollback import config location for configuration "
+                    "molds. Optional. If not provided, rollback is skipped."),
+    # TODO(TheJulia): For now, anaconda can be url based and we can move in
+    # to being tested with glance as soon as we get a public stage2 image.
+    cfg.StrOpt('anaconda_image_ref',
+               help="URL of an anaconda repository to set as image_source"),
+    cfg.StrOpt('anaconda_kernel_ref',
+               help="URL of the kernel to utilize for anaconda deploys."),
+    cfg.StrOpt('anaconda_initial_ramdisk_ref',
+               help="URL of the initial ramdisk to utilize for anaconda "
+                    "deploy operations."),
+    cfg.StrOpt('anaconda_stage2_ramdisk_ref',
+               help="URL of the anaconda second stage ramdisk. Presence of "
+                    "this setting will also determine if a stage2 specific "
+                    "anaconda test is run, or not."),
+    cfg.StrOpt('anaconda_exit_test_at',
+               default='heartbeat',
+               choices=['heartbeat', 'active'],
+               help='When to end the anaconda test job at. Due to '
+                    'the use model of the anaconda driver, as well '
+                    'as the performance profile, the anaconda test is '
+                    'normally only executed until we observe a heartbeat '
+                    'operation indicating that anaconda *has* booted and '
+                    'successfully parsed the URL.'),
     cfg.ListOpt('enabled_drivers',
                 default=['fake', 'pxe_ipmitool', 'agent_ipmitool'],
                 help="List of Ironic enabled drivers."),
@@ -134,8 +193,26 @@ BaremetalGroup = [
     cfg.ListOpt('enabled_raid_interfaces',
                 default=['no-raid', 'agent'],
                 help="List of Ironic enabled RAID interfaces."),
+    cfg.ListOpt('enabled_management_interfaces',
+                default=['fake', 'ipmitool', 'noop'],
+                help="List of Ironic enabled management interfaces."),
+    cfg.ListOpt('enabled_power_interfaces',
+                default=['fake', 'ipmitool'],
+                help="List of Ironic enabled power interfaces."),
     cfg.StrOpt('default_rescue_interface',
                help="Ironic default rescue interface."),
+    cfg.StrOpt('firmware_image_url',
+               help="Image URL of firmware image file supported by "
+                    "update_firmware clean step."),
+    cfg.StrOpt('firmware_image_checksum',
+               help="SHA1 checksum of firmware image file."),
+    cfg.StrOpt('firmware_rollback_image_url',
+               help="Image URL of firmware update cleaning step's "
+                    "rollback image. Optional. If not provided, "
+                    "rollback is skipped."),
+    cfg.StrOpt('firmware_rollback_image_checksum',
+               help="SHA1 checksum of firmware rollback image file. "
+                    "This is required if firmware_rollback_image_url is set."),
     cfg.IntOpt('adjusted_root_disk_size_gb',
                min=0,
                help="Ironic adjusted disk size to use in the standalone tests "
@@ -150,6 +227,13 @@ BaremetalGroup = [
                      "being used, this option should be set to True as "
                      "it lacks the needed components to make it locally "
                      "from a partition image."),
+    cfg.StrOpt('boot_mode',
+               default='bios',
+               choices=['bios', 'uefi'],
+               help="The desired boot_mode to be used on testing nodes."),
+    cfg.StrOpt('default_boot_option',
+               # No good default here, we need to actually set it.
+               help="The default boot option the testing nodes are using."),
 ]
 
 BaremetalFeaturesGroup = [
@@ -166,6 +250,10 @@ BaremetalFeaturesGroup = [
                 help="Defines if software RAID is enabled (available "
                      "starting with Train). Requires at least two disks "
                      "on testing nodes."),
+    cfg.BoolOpt('deploy_time_raid',
+                default=False,
+                help="Defines if in-band RAID can be built in deploy time "
+                     "(possible starting with Victoria)."),
 ]
 
 BaremetalIntrospectionGroup = [
