@@ -22,7 +22,6 @@ from tempest.lib.common import api_version_utils
 from tempest.lib.common.utils.linux import remote_client
 from tempest.lib import exceptions as lib_exc
 
-from ironic_tempest_plugin import clients
 from ironic_tempest_plugin.common import utils
 from ironic_tempest_plugin.common import waiters as ironic_waiters
 from ironic_tempest_plugin import manager
@@ -34,14 +33,13 @@ def retry_on_conflict(func):
     def inner(*args, **kwargs):
         # TODO(vsaienko): make number of retries and delay between
         # them configurable in future.
-        e = None
         for att in range(10):
             try:
                 return func(*args, **kwargs)
-            except lib_exc.Conflict as e:
+            except lib_exc.Conflict:
+                if att == 9:
+                    raise
                 time.sleep(1)
-        raise lib_exc.Conflict(e)
-
     return inner
 
 
@@ -75,7 +73,7 @@ class BaremetalProvisionStates(object):
 
 class BaremetalScenarioTest(manager.ScenarioTest):
 
-    credentials = ['primary', 'admin']
+    credentials = ['primary', 'admin', 'system_admin']
     min_microversion = None
     max_microversion = api_version_utils.LATEST_MICROVERSION
 
@@ -94,8 +92,11 @@ class BaremetalScenarioTest(manager.ScenarioTest):
     @classmethod
     def setup_clients(cls):
         super(BaremetalScenarioTest, cls).setup_clients()
-
-        cls.baremetal_client = clients.Manager().baremetal_client
+        if CONF.enforce_scope.ironic:
+            client = cls.os_system_admin.baremetal.BaremetalClient()
+        else:
+            client = cls.os_admin.baremetal.BaremetalClient()
+        cls.baremetal_client = client
 
     @classmethod
     def resource_setup(cls):
@@ -122,6 +123,16 @@ class BaremetalScenarioTest(manager.ScenarioTest):
         ironic_waiters.wait_node_instance_association(self.baremetal_client,
                                                       instance_id)
 
+    @classmethod
+    def wait_for_agent_heartbeat(cls, node_id, timeout=None):
+        ironic_waiters.wait_node_value_in_field(
+            cls.baremetal_client,
+            node_id=node_id,
+            field='driver_internal_info',
+            value='agent_last_heartbeat',
+            timeout=timeout or CONF.baremetal.deploywait_timeout,
+            interval=10)
+
     @classmethod
     def get_node(cls, node_id=None, instance_id=None, api_version=None):
         return utils.get_node(cls.baremetal_client, node_id, instance_id,
@@ -173,7 +184,7 @@ class BaremetalScenarioTest(manager.ScenarioTest):
     def boot_instance(self, clients=None, keypair=None,
                       net_id=None, fixed_ip=None, **create_kwargs):
         if clients is None:
-            servers_client = self.servers_client
+            servers_client = self.os_primary.servers_client
         else:
             servers_client = clients.servers_client
         if keypair is None:
@@ -223,7 +234,7 @@ class BaremetalScenarioTest(manager.ScenarioTest):
 
     def terminate_instance(self, instance, servers_client=None):
         if servers_client is None:
-            servers_client = self.servers_client
+            servers_client = self.os_primary.servers_client
 
         node = self.get_node(instance_id=instance['id'])
         servers_client.delete_server(instance['id'])
@@ -240,7 +251,7 @@ class BaremetalScenarioTest(manager.ScenarioTest):
                         servers_client=None):
         """Rescue the instance, verify we can ping and SSH."""
         if servers_client is None:
-            servers_client = self.servers_client
+            servers_client = self.os_primary.servers_client
 
         rescuing_instance = servers_client.rescue_server(instance['id'])
         rescue_password = rescuing_instance['adminPass']
@@ -266,8 +277,8 @@ class BaremetalScenarioTest(manager.ScenarioTest):
     def unrescue_instance(self, instance, node, server_ip,
                           servers_client=None):
         if servers_client is None:
-            servers_client = self.servers_client
-        self.servers_client.unrescue_server(instance['id'])
+            servers_client = self.os_primary.servers_client
+        self.os_primary.servers_client.unrescue_server(instance['id'])
         self.wait_provisioning_state(
             node['uuid'],
             BaremetalProvisionStates.ACTIVE,
@@ -275,4 +286,4 @@ class BaremetalScenarioTest(manager.ScenarioTest):
         waiters.wait_for_server_status(servers_client,
                                        instance['id'], 'ACTIVE')
         # Verify server connection
-        self.get_remote_client(server_ip)
+        self.get_remote_client(server_ip, server=instance)
